==> v11.0.1.tar.gz: brewman/brewman/brewman/routers/period.py <==
import uuid

from typing import List

import brewman.schemas.period as schemas

from fastapi import APIRouter, Depends, HTTPException, Request, Security, status
from sqlalchemy import delete, desc, select
from sqlalchemy.exc import SQLAlchemyError

from ..core.security import get_current_active_user as get_user
from ..core.session import get_finish_date, get_start_date
from ..db.session import SessionFuture
from ..models.period import Period
from ..schemas.user import UserToken


router = APIRouter()


@router.post("", response_model=schemas.Period)
def save(
    data: schemas.PeriodIn,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    try:
        with SessionFuture() as db:
            item = Period(valid_from=data.valid_from, valid_till=data.valid_till)
            db.add(item)
            db.commit()
            return period_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.put("/{id_}", response_model=schemas.Period)
def update_route(
    id_: uuid.UUID,
    data: schemas.PeriodIn,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    try:
        with SessionFuture() as db:
            item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
            item.valid_from = data.valid_from
            item.valid_till = data.valid_till
            db.commit()
            return period_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.delete("/{id_}", response_model=None)
def delete_route(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> None:
    with SessionFuture() as db:
        item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
        db.execute(delete(Period).where(Period.id == item.id))
        db.commit()


@router.get("", response_model=schemas.PeriodIn)
def show_blank(
    request: Request,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.PeriodIn:
    return period_blank(request)


@router.get("/list", response_model=List[schemas.Period])
async def show_list(user: UserToken = Depends(get_user)) -> List[schemas.Period]:
    with SessionFuture() as db:
        return [
            period_info(item) for item in db.execute(select(Period).order_by(desc(Period.valid_from))).scalars().all()
        ]


@router.get("/{id_}", response_model=schemas.Period)
def show_id(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    with SessionFuture() as db:
        item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
        return period_info(item)


def period_info(item: Period) -> schemas.Period:
    return schemas.Period(
        id=item.id,
        validFrom=item.valid_from,
        validTill=item.valid_till,
    )


def period_blank(request: Request) -> schemas.PeriodIn:
    return schemas.PeriodIn(
        validFrom=get_start_date(request.session),
        validTill=get_finish_date(request.session),
    )

==> v11.1.2.tar.gz: brewman/brewman/brewman/routers/period.py <==
import uuid

import brewman.schemas.period as schemas

from fastapi import APIRouter, Depends, HTTPException, Request, Security, status
from sqlalchemy import delete, desc, select
from sqlalchemy.exc import SQLAlchemyError

from ..core.security import get_current_active_user as get_user
from ..core.session import get_finish_date, get_start_date
from ..db.session import SessionFuture
from ..models.period import Period
from ..schemas.user import UserToken


router = APIRouter()


@router.post("", response_model=schemas.Period)
def save(
    data: schemas.PeriodIn,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    try:
        with SessionFuture() as db:
            item = Period(valid_from=data.valid_from, valid_till=data.valid_till)
            db.add(item)
            db.commit()
            return period_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.put("/{id_}", response_model=schemas.Period)
def update_route(
    id_: uuid.UUID,
    data: schemas.PeriodIn,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    try:
        with SessionFuture() as db:
            item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
            item.valid_from = data.valid_from
            item.valid_till = data.valid_till
            db.commit()
            return period_info(item)
    except SQLAlchemyError as e:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=str(e),
        )


@router.delete("/{id_}", response_model=None)
def delete_route(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> None:
    with SessionFuture() as db:
        item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
        db.execute(delete(Period).where(Period.id == item.id))
        db.commit()


@router.get("", response_model=schemas.PeriodIn)
def show_blank(
    request: Request,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.PeriodIn:
    return period_blank(request)


@router.get("/list", response_model=list[schemas.Period])
async def show_list(user: UserToken = Depends(get_user)) -> list[schemas.Period]:
    with SessionFuture() as db:
        return [
            period_info(item) for item in db.execute(select(Period).order_by(desc(Period.valid_from))).scalars().all()
        ]


@router.get("/{id_}", response_model=schemas.Period)
def show_id(
    id_: uuid.UUID,
    user: UserToken = Security(get_user, scopes=["recipes"]),
) -> schemas.Period:
    with SessionFuture() as db:
        item: Period = db.execute(select(Period).where(Period.id == id_)).scalar_one()
        return period_info(item)


def period_info(item: Period) -> schemas.Period:
    return schemas.Period(
        id_=item.id,
        valid_from=item.valid_from,
        valid_till=item.valid_till,
    )


def period_blank(request: Request) -> schemas.PeriodIn:
    return schemas.PeriodIn(
        valid_from=get_start_date(request.session),  # type: ignore[arg-type]
        valid_till=get_finish_date(request.session),  # type: ignore[arg-type]
    )
